@@ -7,7 +7,7 @@ from django.db.models.base import ModelBase
 from django.template.defaultfilters import slugify, truncatewords_html
 from django.utils.translation import ugettext, ugettext_lazy as _
 
-from mezzanine.core.managers import PublishedManager, KeywordManager
+from mezzanine.core.managers import DisplayableManager, KeywordManager
 from mezzanine import settings as blog_settings
 
 
@@ -30,9 +30,11 @@ class Displayable(models.Model):
     slug = models.SlugField(max_length=100, editable=False, null=True)
     keywords = models.ManyToManyField("Keyword", verbose_name=_("Keywords"),
         blank=True)
+    _keywords = models.CharField(max_length=500, editable=False)
     short_url = models.URLField(blank=True, null=True)
         
-    objects = PublishedManager()
+    objects = DisplayableManager()
+    search_fields = {"_keywords": 10, "title": 5, "content": 1}
 
     class Meta:
         abstract = True
@@ -71,7 +73,15 @@ class Displayable(models.Model):
                     break
                 i += 1
         super(Displayable, self).save(*args, **kwargs)
-        
+    
+    def set_searchable_keywords(self):
+        """
+        Stores the keywords as a single string into the ``_keywords`` field 
+        for convenient access when searching.
+        """
+        self._keywords = " ".join([kw.value for kw in self.keywords.all()])
+        self.save()
+    
     def get_slug(self):
         return slugify(self.title)
     
@@ -83,10 +93,10 @@ class Displayable(models.Model):
 
 class OrderableBase(ModelBase):
     """
-    Checks for order_with_respect_to on the model's inner Meta class and if 
-    found, copies it to a custom attribute and deletes it since it will cause 
-    errors when used with ForeignKey("self"). Also specify ordering on the Meta 
-    class if not yet provided.
+    Checks for ``order_with_respect_to`` on the model's inner ``Meta`` class 
+    and if found, copies it to a custom attribute and deletes it since it 
+    will cause errors when used with ``ForeignKey("self")``. Also creates the  
+    ``ordering`` attribute on the ``Meta`` class if not yet provided.
     """
 
     def __new__(cls, name, bases, attrs):
@@ -104,8 +114,8 @@ class OrderableBase(ModelBase):
 class Orderable(models.Model):
     """
     Provide a custom ordering integer field similar to using Meta's 
-    order_with_respect_to since to date (Django 1.2) order_with_respect_to 
-    doesn't work with ForeignKey("self"). We may also want this feature for 
+    ``order_with_respect_to`` since to date (Django 1.2) this doesn't work 
+    with ``ForeignKey("self")``. We may also want this feature for 
     models that aren't ordered with respect to a particular field.
     """
 
@@ -119,7 +129,7 @@ class Orderable(models.Model):
     def with_respect_to(self):
         """
         Returns a dict to use as a filter for ordering operations containing 
-        the original Meta.order_with_respect_to value if provided.
+        the original ``Meta.order_with_respect_to`` value if provided.
         """
         try:
             field = self.order_with_respect_to
