@@ -17,10 +17,10 @@ def admin_page_ordering(request):
     """
     for i, page in enumerate(request.POST.get("ordering", "").split(",")):
         try:
-            Page.objects.filter(id=page.split("_")[-1]).update(ordering=i)
-        except ValueError:
-            pass
-    return HttpResponse("")
+            Page.objects.filter(id=page.split("_")[-1]).update(_order=i)
+        except Exception, e:
+            return HttpResponse(str(e))
+    return HttpResponse("ok")
 admin_page_ordering = staff_member_required(admin_page_ordering)
 
 def page(request, slug, template="pages/page.html"):
